@@ -24,9 +24,6 @@ def set_new_proxy():
     return pg
 
 
-set_new_proxy()
-
-
 def getAuthorData(scholarId: str):
     """
     Retrieve the author's data from Google Scholar.
@@ -49,13 +46,13 @@ def crawl(scholarID: str):
     """
     data = None
     iter = 0
-    while iter < 10:
+    while iter < 10 and data is None:
         try:
             data = getAuthorData(scholarID)
-            return data
-        except Exception as e:
+        except:
             set_new_proxy()
             iter += 1
+            data = None
 
     return data
 
@@ -88,6 +85,11 @@ class ScholarScraper:
         self.scholarIds = scholarIds if scholarIds else self.scholarIds
         self.max_threads = max_threads if max_threads else self.max_threads
 
+        if self.max_threads == 1:
+            for scholarId in self.scholarIds:
+                self.authorsList.append(getAuthorData(scholarId))
+            return json.dumps(self.authorsList, cls=JSONEncoder, sort_keys=True, indent=4, ensure_ascii=False)
+
         # Use many threads (self.max_threads max, or one for each scholarId)
         num_threads = min(self.max_threads, len(self.scholarIds))
 
